|
From: <p3t...@us...> - 2007-05-20 18:52:59
|
Revision: 985
http://svn.sourceforge.net/hackndev/?rev=985&view=rev
Author: p3t3-dev
Date: 2007-05-20 11:52:57 -0700 (Sun, 20 May 2007)
Log Message:
-----------
Treo650: power management wake-up modifications
Modified Paths:
--------------
linux4palm/linux/trunk/arch/arm/mach-pxa/palmt650/palmt650_pm.c
Modified: linux4palm/linux/trunk/arch/arm/mach-pxa/palmt650/palmt650_pm.c
===================================================================
--- linux4palm/linux/trunk/arch/arm/mach-pxa/palmt650/palmt650_pm.c 2007-05-20 18:49:06 UTC (rev 984)
+++ linux4palm/linux/trunk/arch/arm/mach-pxa/palmt650/palmt650_pm.c 2007-05-20 18:52:57 UTC (rev 985)
@@ -1,8 +1,9 @@
/************************************************************************
- * PalmOne Zire72 suspend/resume support *
+ * PalmOne treo650 suspend/resume support *
* *
* Authors: Jan Herman <2h...@se...> *
* Sergey Lapin <sla...@gm...> *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License version 2 as *
@@ -24,7 +25,6 @@
#include <asm/arch/pxa-regs.h>
#include <asm/arch/palmt650-gpio.h>
-#include <asm/arch/pxa27x_keyboard.h>
#ifdef CONFIG_PM
static int palmt650_suspend(struct device *dev, pm_message_t state)
@@ -32,8 +32,8 @@
/* Wake-Up on RTC event, etc. */
PWER |= PWER_RTC | PWER_WEP1;
- /* Wakeup by keyboard :) */
- PKWR = 0xe0000;
+ /* Wakeup by keyboard :-) */
+ PKWR = 0x01;
/* Enabled Deep-Sleep mode */
PCFR |= PCFR_DS;
@@ -47,15 +47,12 @@
/* Turn off LCD power */
SET_PALMT650_GPIO(LCD_POWER,0);
- /* Turn screen off */
- SET_PALMT650_GPIO(LCD_SCREEN,0);
/* Turn off USB power */
/* SET_PALMT650_GPIO(USB_POWER,0); */
-
+
/* disable GPIO reset - DO NOT REMOVE! */
PCFR = PCFR_GPROD;
-/* PCFR &= PCFR_GPR_EN; */
return 0;
}
@@ -74,10 +71,8 @@
/* Turn on LCD power */
SET_PALMT650_GPIO(LCD_POWER,1);
- /* Turn screen on */
- SET_PALMT650_GPIO(LCD_SCREEN,1);
/* Turn on USB power */
-/* SET_PALMT650_GPIO(USB_POWER,1); */
+/* SET_PALMT650_GPIO(USB_POWER,1); */
return 0;
}
@@ -89,7 +84,7 @@
static void palmt650_pxa_ll_pm_suspend(unsigned long resume_addr)
{
/* For future */
- return;
+ return;
}
static void palmt650_pxa_ll_pm_resume(void)
@@ -129,6 +124,6 @@
module_init(palmt650_pm_init);
module_exit(palmt650_pm_exit);
-MODULE_AUTHOR("Jan Herman <2h...@se...>, Sergey Lapin <sla...@gm...>");
+MODULE_AUTHOR("P3T3 Petr Blaha <pb...@p3...>, Jan Herman <2h...@se...>, Sergey Lapin <sla...@gm...>");
MODULE_DESCRIPTION("PalmOne Treo 650 power management driver");
MODULE_LICENSE("GPL");
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -1,8 +1,9 @@
* *
- * Authors: Jan Herman <2h...@se...> *
- * Sergey Lapin <sla...@gm...> *
+ * Authors: P3T3, Petr Blaha <pb...@p3...> *
+ * Jan Herman <2h...@se...> *
+ * Sergey Lapin <sla...@gm...> *
* *
* This program is free software; you can redistribute it and/or modify *
|